@@ -16,17 +16,21 @@ from .assertion_engine import (
     AssertionOperator,
     bool_verify_assertion,
     dict_verify_assertion,
+    flag_verify_assertion,
     float_str_verify_assertion,
     int_dict_verify_assertion,
     list_verify_assertion,
     verify_assertion,
 )
+from .formatter import Formatter
 
 __all__ = [
     "AssertionOperator",
+    "Formatter",
     "bool_verify_assertion",
     "dict_verify_assertion",
     "float_str_verify_assertion",
+    "flag_verify_assertion",
     "int_dict_verify_assertion",
     "list_verify_assertion",
     "verify_assertion",
